@@ -2,7 +2,10 @@ from __future__ import absolute_import
 
 __all__ = ["mycobot", "genre"]
 
-__version__ = "2.3.6"
+__version__ = "2.4.1"
 __author__ = "Zachary zhang"
 __email__ = "lijun.zhang@elephantrobotics.com"
 __git_url__ = "https://github.com/elephantrobotics/pymycobot"
+
+PI_PORT = "/dev/ttyAMA0"
+PI_BAUD = 1000000
