@@ -19,6 +19,8 @@ class MyCobot(MyCobotData):
             power_on()
             power_off()
             is_power_on()
+            release_all_servos()
+            is_controller_connected()
             set_free_mode()
 
         # MDI mode and operation
@@ -55,6 +57,9 @@ class MyCobot(MyCobotData):
         # Servo control
             is_servo_enable()
             is_all_servo_enable()
+            set_servo_data()
+            get_servo_data()
+            set_servo_calibration()
             release_servo()
             focus_servo()
 
@@ -80,20 +85,19 @@ class MyCobot(MyCobotData):
             wait() *
     """
 
-    def __init__(self, port, boudrate="115200", timeout=0.1, debug=False):
+    def __init__(self, port, baudrate="115200", timeout=0.1, debug=False):
         """
         Args:
             port     : port string
-            boudrate : baud rate string, default '115200'
+            baudrate : baud rate string, default '115200'
             timeout  : default 0.1
             debug    : whether show debug info
-
         """
         self._version = sys.version_info[:2][0]
         self.debug = debug
         setup_logging(self.debug)
         self.log = logging.getLogger(__name__)
-        self._serial_port = serial.Serial(port, boudrate, timeout=timeout)
+        self._serial_port = serial.Serial(port, baudrate, timeout=timeout)
 
     def _write(self, command):
         self.log.debug("_write: {}".format(command))
@@ -122,7 +126,6 @@ class MyCobot(MyCobotData):
                    the array is used to include them. (Data cannot be nested)
             **kwargs: support `has_reply`
                 has_reply: Whether there is a return value to accept.
-
         """
         command_data = self._process_data_command(args)
 
@@ -142,18 +145,18 @@ class MyCobot(MyCobotData):
             res = self._process_received(data, genre)
             return res
 
-    # Overall status
+    # System status
     def version(self):  # TODO: test method <11-03-21, yourname> #
         """Get cobot version
 
         Return:
             mycobot   : 1
             mycobotPro: 101
-
         """
         recv = self.__mesg(Command.VERSION, has_reply=True)
         return recv
 
+    # Overall status
     def power_on(self):
         self.__mesg(Command.POWER_ON)
 
@@ -167,13 +170,27 @@ class MyCobot(MyCobotData):
             1 : power on
             0 : power off
             -1: error data
-
         """
         return self._process_single(self.__mesg(Command.IS_POWER_ON, has_reply=True))
 
-    def set_free_mode(self):
-        # self._write('fefe0213fa')
-        self.__mesg(Command.SET_FREE_MODE)
+    def release_all_servos(self):
+        self.__mesg(Command.RELEASE_ALL_SERVOS)
+
+    def is_controller_connected(self):
+        return self._process_single(
+            self.__mesg(Command.IS_CONTROLLER_CONNECTED, has_reply=True)
+        )
+
+    """
+    def set_free_mode(self, flag):  # TODO:no finish
+        if flag:
+            self.__mesg(Command.SET_FREE_MODE, 1)
+        else:
+            self.__mesg(Command.SET_FREE_MODE, 0)
+
+    def is_free_mode(self):  # TODO: no finish
+        return self._process_single(self.__mesg(Command.IS_FREE_MODE, has_reply=True))
+    """
 
     # MDI mode and operation
     def get_angles(self):
@@ -181,7 +198,6 @@ class MyCobot(MyCobotData):
 
         Return:
             data_list (list[angle...]):
-
         """
         angles = self.__mesg(Command.GET_ANGLES, has_reply=True)
         return [self._int_to_angle(angle) for angle in angles]
@@ -194,7 +210,6 @@ class MyCobot(MyCobotData):
             id (common.Angle):
             degree (float):
             speed (int): 0 ~100
-
         """
         self.__mesg(Command.SEND_ANGLE, id - 1, [self._angle_to_int(degree)], speed)
 
@@ -205,7 +220,6 @@ class MyCobot(MyCobotData):
         Args:
             degrees (list): example [0.0, 0.0, 0.0, 0.0, 0.0, 0.0]
             speed (int): 0 ~ 100
-
         """
         degrees = [self._angle_to_int(degree) for degree in degrees]
         # data = [degrees, speed]
@@ -226,7 +240,6 @@ class MyCobot(MyCobotData):
 
         Return:
             data_list (list[radian...]):
-
         """
         angles = self.__mesg(Command.GET_ANGLES, has_reply=True)
         return [
@@ -239,7 +252,6 @@ class MyCobot(MyCobotData):
         Args:
             radians (list): example [0, 0, 0, 0, 0, 0]
             speed (int): 0 ~ 100
-
         """
         degrees = [self._angle_to_int(radian * (180 / math.pi)) for radian in radians]
         return self.__mesg(Command.SEND_ANGLES, degrees, speed)
@@ -249,7 +261,6 @@ class MyCobot(MyCobotData):
 
         Return:
             data_list (list): [x, y, z, rx, ry, rz]
-
         """
         received = self.__mesg(Command.GET_COORDS, has_reply=True)
         if not received:
@@ -268,9 +279,8 @@ class MyCobot(MyCobotData):
 
         Args:
             id(common.Coord):
-            coord(fload): mm
+            coord(float): mm
             speed(int):
-
         """
         return self.__mesg(
             Command.SEND_COORD, id - 1, [self._coord_to_int(coord)], speed
@@ -284,7 +294,6 @@ class MyCobot(MyCobotData):
             coords: [x(mm), y, z, rx(angle), ry, rz]
             speed(int);
             mode(int): 0 - angluar, 1 - linear
-
         """
         coord_list = []
         for idx in range(3):
@@ -341,7 +350,7 @@ class MyCobot(MyCobotData):
         received = self.__mesg(Command.IS_IN_POSITION, data_list, id, has_reply=True)
         return self._process_single(received)
 
-    def is_moving(self):  # TODO: wait atom finish.
+    def is_moving(self):
         """
 
         Return:
@@ -378,10 +387,16 @@ class MyCobot(MyCobotData):
         self.__mesg(Command.JOG_STOP)
 
     def set_encoder(self, joint_id, encoder):
-        self.__mesg(Command.SET_ENCODER, joint_id, [encoder])
+        """Set joint encoder value.
+
+        Args:
+            joint_id: Joint id 1 - 7
+            encoder: The value of the set encoder.
+        """
+        self.__mesg(Command.SET_ENCODER, joint_id - 1, [encoder])
 
     def get_encoder(self, joint_id):
-        return self.__mesg(Command.GET_ENCODER, joint_id, has_reply=True)
+        return self.__mesg(Command.GET_ENCODER, joint_id - 1, has_reply=True)
 
     def set_encoders(self, encoders, sp):
         self.__mesg(Command.SET_ENCODERS, encoders, sp)
@@ -400,6 +415,18 @@ class MyCobot(MyCobotData):
         self.__mesg(Command.SET_SPEED, speed)
         return self
 
+    """
+    def get_feed_override(self):
+        return self._process_single(
+            self.__mesg(Command.GET_FEED_OVERRIDE, has_reply=True)
+        )
+
+    def get_acceleration(self):
+        return self._process_single(
+            self.__mesg(Command.GET_ACCELERATION, has_reply=True)
+        )
+    """
+
     @check_parameters(Command.GET_JOINT_MIN_ANGLE)
     def get_joint_min_angle(self, joint_id):
         angle = self.__mesg(Command.GET_JOINT_MIN_ANGLE, joint_id, has_reply=True)
@@ -413,13 +440,24 @@ class MyCobot(MyCobotData):
     # Servo control
     @check_parameters(Command.IS_SERVO_ENABLE)
     def is_servo_enable(self, servo_id):
-        return self._process_single(self.__mesg(Command.IS_SERVO_ENABLE, servo_id))
+        return self._process_single(self.__mesg(Command.IS_SERVO_ENABLE, servo_id - 1))
 
     def is_all_servo_enable(self):
         return self._process_single(
             self.__mesg(Command.IS_ALL_SERVO_ENABLE, has_reply=True)
         )
 
+    def set_servo_data(self, servo_no, data_id, value):
+        self.__mesg(Command.SET_SERVO_DATA, servo_no - 1, data_id, value)
+
+    def get_servo_data(self, servo_no, data_id):
+        return self._process_single(
+            self.__mesg(Command.GET_SERVO_DATA, servo_no - 1, data_id, has_reply=True)
+        )
+
+    def set_servo_calibration(self, servo_no):
+        self.__mesg(Command.SET_SERVO_CALIBRATION, servo_no - 1)
+
     @check_parameters(Command.RELEASE_SERVO)
     def release_servo(self, servo_id):
         """Power off designated servo
@@ -455,12 +493,11 @@ class MyCobot(MyCobotData):
         return self
 
     def set_pin_mode(self, pin_no, pin_mode):
-        """
+        """Set the state mode of the specified pin in atom.
 
         Args:
             pin_no   (int):
             pin_mode (int): 0 - input, 1 - output, 2 - input_pullup
-
         """
         self.__mesg(Command.SET_PIN_MODE, pin_no, pin_mode)
 
@@ -470,7 +507,6 @@ class MyCobot(MyCobotData):
         Args:
             pin_no     (int):
             pin_signal (int): 0 / 1
-
         """
         self.__mesg(Command.SET_DIGITAL_OUTPUT, pin_no, pin_signal)
 
@@ -497,7 +533,6 @@ class MyCobot(MyCobotData):
         Args:
             flag  (int): 0 - open, 1 - close
             speed (int): 0 ~ 100
-
         """
         self.__mesg(Command.SET_GRIPPER_STATE, flag, speed)
         return self
@@ -508,7 +543,6 @@ class MyCobot(MyCobotData):
         Args:
             value (int): 0 ~ 4096
             speed (int): 0 ~ 100
-
         """
         self.__mesg(Command.SET_GRIPPER_VALUE, [value], speed)
 
@@ -516,7 +550,6 @@ class MyCobot(MyCobotData):
         """Set the current position to zero
 
         Current position value is `2048`.
-
         """
         self.__mesg(Command.SET_GRIPPER_INI)
 
@@ -527,19 +560,17 @@ class MyCobot(MyCobotData):
             0 : not moving
             1 : is moving
             -1: error data
-
         """
         return self._process_single(
             self.__mesg(Command.IS_GRIPPER_MOVING, has_reply=True)
         )
 
-    # Baisc
+    # Basic
     def set_basic_output(self, pin_no, pin_signal):
         """
 
         Args:
             pin_signal: 0 / 1
-
         """
         self.__mesg(Command.SET_BASIC_OUTPUT, pin_no, pin_signal)
         return self
